==> hermes-6.0.3.5.rec2.tar.gz: hermes-6.0.3.5.rec2/spec/factories/housing_offers_factory.rb <==
# frozen_string_literal: true

require 'faker'

FactoryBot.define do
  factory :housing_offer, class: Hermes::HousingOffer do
    reserving_siren { '824541148' }
    address { Faker::Address.street_address }
    availability_date { DateTime.current + 1.month }
    construction_type { Faker::Name.name }
    dpe_conso  { ['A', 'B', 'C', 'D', 'E', 'F', 'G'].sample }
    dpe_ges  { ['A', 'B', 'C', 'D', 'E', 'F', 'G'].sample }
    external_ref { Faker::Name.name }
    kind { Faker::Name.name  }
    lessor_contact_name { Faker::Name.name  }
    postal_code { '34000' }
    rent_amount { rand(300..500) }
    rental_charges { rand(100..200) }
    residence_title { Faker::Name.name  }
    surface { rand(20..120) }
    threshold_subtype { 'PLU' }
    threshold_type { 'Paris et communes limitrophes' }
    typology { 'T1' }

    trait :with_lessor do
      association :lessor, factory: :lessor
    end

    trait :with_eligible_requests do 
      transient do
        requests_count { 1 }
      end
      typology { 'T1' }
      insee_code { '34000' }
      ceil_category_1 = 25000
      offer_status { 'LOGEMENT PUBLIE' }
      ceil_category_1 { ceil_category_1 }
      ceil_category_2 { (ceil_category_1 * 2) }
      ceil_category_3 { (ceil_category_1 * 3) }
      ceil_category_4 { (ceil_category_1 * 4) }
      ceil_category_5 { (ceil_category_1 * 5) }
      ceil_category_6 { (ceil_category_1 * 6) }
      ceil_category_7 { (ceil_category_1 * 7) }
      ceil_category_8 { (ceil_category_1 * 8) }
      ceil_category_9 { (ceil_category_1 * 9) }
      ceil_category_10 { (ceil_category_1 * 10) }
      ceil_category_11 { (ceil_category_1 * 11) }
      ceil_category_12 { (ceil_category_1 * 12) }
      floor_category_1 { 0.0 }
      floor_category_2 { 0.0 }
      floor_category_3 { 0.0 }
      floor_category_4 { 0.0 }
      floor_category_5 { 0.0 }
      floor_category_6 { 0.0 }
      floor_category_7 { 0.0 }
      floor_category_8 { 0.0 }
      floor_category_9 { 0.0 }
      floor_category_10 { 0.0 }
      floor_category_11 { 0.0 }
      floor_category_12 { 0.0 }

      after(:create) do |housing_offer, evaluator|
        housing_requests = create_list(:complete_request, evaluator.requests_count)
      end

    end 
    
    before(:create) do |order, evaluator|
      Hermes::ReservationHolder.create_default
    end
    
    after(:build) do |hous_off|
      if hous_off.class.name == 'Hermes::HousingOffer'
        hous_off.class.skip_callback(:create, :after, :call_geocode, raise: false)
      end
    end
  end

  factory :published_offer, parent: :housing_offer do
    insee_code { '34000' }
    date_publication_start { Time.new(2020, 3, 15, 0, 0, 0) }
    offer_status { 'LOGEMENT PUBLIE' }
    lessor_status { "PUBLIE" }
    max_applicants { 3 }

    trait :with_applications do
      transient do
        applications_count { 2 }
        housing_request { nil }
      end

      after :create do |offer, evaluator|
        request = evaluator.housing_request.presence || create(:active_request)
        evaluator.applications_count.times do
          create(:housing_application, housing_offer: offer, housing_request: request)
        end
      end
    end
  end
end

==> hermes-6.0.3.20.rec2.tar.gz: hermes-6.0.3.20.rec2/spec/factories/housing_offers_factory.rb <==
# frozen_string_literal: true

require 'faker'

FactoryBot.define do
  factory :housing_offer, class: Hermes::HousingOffer do
    reserving_siren { '824541148' }
    address { Faker::Address.street_address }
    availability_date { DateTime.current + 1.month }
    construction_type { Faker::Name.name }
    dpe_conso  { ['A', 'B', 'C', 'D', 'E', 'F', 'G'].sample }
    dpe_ges  { ['A', 'B', 'C', 'D', 'E', 'F', 'G'].sample }
    external_ref { Faker::Name.name }
    kind { Faker::Name.name  }
    lessor_contact_name { Faker::Name.name  }
    postal_code { '34000' }
    rent_amount { rand(300..500) }
    rental_charges { rand(100..200) }
    residence_title { Faker::Name.name  }
    surface { rand(20..120) }
    threshold_subtype { 'PLU' }
    threshold_type { 'Paris et communes limitrophes' }
    typology { 'T1' }

    trait :with_lessor do
      association :lessor, factory: :lessor
    end

    trait :with_eligible_requests do 
      transient do
        requests_count { 1 }
      end
      insee_code { '34000' }
      ceil_category_1 = 25000
      offer_status { 'LOGEMENT PUBLIE' }
      ceil_category_1 { ceil_category_1 }
      ceil_category_2 { (ceil_category_1 * 2) }
      ceil_category_3 { (ceil_category_1 * 3) }
      ceil_category_4 { (ceil_category_1 * 4) }
      ceil_category_5 { (ceil_category_1 * 5) }
      ceil_category_6 { (ceil_category_1 * 6) }
      ceil_category_7 { (ceil_category_1 * 7) }
      ceil_category_8 { (ceil_category_1 * 8) }
      ceil_category_9 { (ceil_category_1 * 9) }
      ceil_category_10 { (ceil_category_1 * 10) }
      ceil_category_11 { (ceil_category_1 * 11) }
      ceil_category_12 { (ceil_category_1 * 12) }
      floor_category_1 { 0.0 }
      floor_category_2 { 0.0 }
      floor_category_3 { 0.0 }
      floor_category_4 { 0.0 }
      floor_category_5 { 0.0 }
      floor_category_6 { 0.0 }
      floor_category_7 { 0.0 }
      floor_category_8 { 0.0 }
      floor_category_9 { 0.0 }
      floor_category_10 { 0.0 }
      floor_category_11 { 0.0 }
      floor_category_12 { 0.0 }

      after(:create) do |housing_offer, evaluator|
        housing_requests = create_list(:complete_request, evaluator.requests_count)
      end

    end 
    
    before(:create) do |order, evaluator|
      Hermes::ReservationHolder.create_default
    end
    
    after(:build) do |hous_off|
      if hous_off.class.name == 'Hermes::HousingOffer'
        hous_off.class.skip_callback(:create, :after, :call_geocode, raise: false)
      end
    end
  end

  factory :published_offer, parent: :housing_offer do
    insee_code { '34000' }
    date_publication_start { Time.new(2020, 3, 15, 0, 0, 0) }
    offer_status { 'LOGEMENT PUBLIE' }
    lessor_status { "PUBLIE" }
    max_applicants { 3 }

    trait :with_applications do
      transient do
        applications_count { 2 }
        housing_request { nil }
      end

      after :create do |offer, evaluator|
        evaluator.applications_count.times do
          request = evaluator.housing_request.presence || create(:complete_request)
          create(:housing_application, housing_offer: offer, housing_request: request)
        end
      end
    end
  end
end
